import * as p_safe from 'p-safe';
import { SafeReturn } from 'p-safe';
import * as z from 'zod';

declare const ClientOptionsSchema: z.ZodObject<{
    endpoint: z.ZodOptional<z.ZodString>;
    apiVersion: z.ZodOptional<z.ZodString>;
    pathPrefix: z.ZodOptional<z.ZodString>;
    token: z.ZodOptional<z.ZodString>;
    namespace: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    endpoint?: string | undefined;
    apiVersion?: string | undefined;
    pathPrefix?: string | undefined;
    token?: string | undefined;
    namespace?: string | undefined;
}, {
    endpoint?: string | undefined;
    apiVersion?: string | undefined;
    pathPrefix?: string | undefined;
    token?: string | undefined;
    namespace?: string | undefined;
}>;

interface ClientOptions extends Infer<typeof ClientOptionsSchema> {
    request?: Partial<RequestInit & Record<string, unknown>>;
    fetcher?: Fetcher;
}
interface RequestSchema {
    path?: z.ZodObject<any>;
    body?: z.ZodObject<any> | z.ZodRecord<any>;
    searchParams?: z.ZodObject<any>;
    headers?: z.ZodObject<any>;
    response?: z.ZodType<unknown>;
}
interface Fetcher {
    (input: any, init: any): Promise<any>;
}
interface CommandOptions extends Omit<RequestInit, 'url'>, Record<string, unknown> {
    strictSchema?: boolean;
}
interface RequestInitWithURL extends RequestInit {
    url: URL;
}
interface CommandInit<Schema extends RequestSchema, RawResponse extends boolean = false> {
    method: RequestInit['method'];
    path: string;
    schema: Schema;
    client: ClientOptions;
    raw?: RawResponse;
    refine?: (init: RequestInitWithURL, args: CommandArgs<Schema>) => RequestInitWithURL;
    fetcher?: Fetcher;
}
type CommandArgs<Schema extends RequestSchema> = Infer<Schema['path']> & Infer<Schema['searchParams']> & Infer<Schema['headers']> & Infer<Schema['body']> & {
    [key: string]: unknown;
};
type Infer<T> = T extends z.ZodSchema ? z.infer<T> : T;

declare class ApiSector {
    protected readonly client: Client;
    constructor(client: Client);
}

/**
 * AWS secrets engine (API)
 *
 * @link https://developer.hashicorp.com/vault/api-docs/secret/aws
 */
declare class Aws extends ApiSector {
    /**
     * IAM
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#iam
     */
    get config(): (args?: ({
        max_retries?: number | undefined;
        access_key?: string | undefined;
        secret_key?: string | undefined;
        role_arn?: string | undefined;
        identity_token_audience?: string | undefined;
        identity_token_ttl?: string | undefined;
        region?: string | undefined;
        iam_endpoint?: string | undefined;
        sts_endpoint?: string | undefined;
        username_template?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Read root configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#read-root-configuration
     */
    get rootInfo(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Rotate root IAM credentials
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#rotate-root-iam-credentials
     */
    get rotateRoot(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Configure lease
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#configure-lease
     */
    get configLease(): (args?: ({
        lease: string;
        lease_max: number;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Read lease
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#read-lease
     */
    get lease(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Create/Update role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#create-update-role
     */
    get role(): (args?: ({
        name: string;
        credential_type: string;
        role_arns?: string[] | undefined;
        policy_arns?: string[] | undefined;
        policy_document?: string | undefined;
        iam_groups?: string[] | undefined;
        iam_tags?: string[] | undefined;
        default_sts_ttl?: string | undefined;
        max_sts_ttl?: string | undefined;
        user_path?: string | undefined;
        permissions_boundary_arn?: string | undefined;
        mfa_serial_number?: string | undefined;
        policy?: string | undefined;
        arn?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Read role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#read-role
     */
    get roleInfo(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * List roles
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#list-roles
     */
    get roles(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Delete role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#delete-role
     */
    get deleteRole(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Generate credentials for the path `/aws/creds/:name`
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#generate-credentials
     */
    get credentials(): (args?: ({
        name: string;
    } & {
        role_arn?: string | undefined;
        role_session_name?: string | undefined;
        ttl?: string | undefined;
        mfa_code?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Generate credentials for the path `/aws/sts/:name`
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#generate-credentials
     */
    get stsCredentials(): (args?: ({
        name: string;
    } & {
        role_arn?: string | undefined;
        role_session_name?: string | undefined;
        ttl?: string | undefined;
        mfa_code?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Create/Update static role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#create-update-static-role
     */
    get staticRole(): (args?: ({
        name: string;
    } & {
        username: string;
        rotation_period: string | number;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Read static role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#read-static-role
     */
    get staticRoleInfo(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Delete static role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#delete-static-role
     */
    get deleteStaticRole(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
    /**
     * Get static credentials
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/aws#get-static-credentials
     */
    get staticCredentials(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<any, VaultError>>;
}

/**
 * Kubernetes secrets engine (API)
 *
 * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes
 */
declare class Kubernetes extends ApiSector {
    /**
     * Write configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#write-configuration
     */
    get config(): (args?: ({
        kubernetes_host?: string | undefined;
        kubernetes_ca_cert?: string | undefined;
        service_account_jwt?: string | undefined;
        disable_local_ca_jwt?: boolean | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Read configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#read-configuration
     */
    get readConfig(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Delete configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#delete-configuration
     */
    get deleteConfig(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Create role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#create-role
     */
    get createRole(): (args?: ({
        name: string;
    } & {
        allowed_kubernetes_namespaces?: string[] | undefined;
        allowed_kubernetes_namespace_selector?: string | undefined;
        token_max_ttl?: string | undefined;
        token_default_ttl?: string | undefined;
        token_default_audiences?: string | undefined;
        service_account_name?: string | undefined;
        kubernetes_role_name?: string | undefined;
        kubernetes_role_type?: string | undefined;
        generated_role_rules?: string | undefined;
        name_template?: string | undefined;
        extra_annotations?: Record<string, string> | undefined;
        extra_labels?: Record<string, string> | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Read role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#read-role
     */
    get role(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * List roles
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#list-roles
     */
    get roles(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Delete role
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#delete-role
     */
    get deleteRole(): (args?: ({
        name: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Generate credentials
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kubernetes#generate-credentials
     */
    get generateCreds(): (args?: ({
        name: string;
    } & {
        role: string;
        ttl?: string | undefined;
        kubernetes_namespace?: string | undefined;
        cluster_role_binding?: boolean | undefined;
        audiences?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
}

/**
 * KV secrets engine - version 1
 *
 * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v1
 */
declare class Kv extends ApiSector {
    /**
     * Read secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v1#read-secret
     */
    get read(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: Record<string, any>;
    }, VaultError>>;
    /**
     * List secrets
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v1#list-secrets
     */
    get list(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            keys: string[];
        };
    }, VaultError>>;
    /**
     * Create/Update secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v1#create-update-secret
     */
    get write(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        data: Record<string, any>;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Delete secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v1#delete-secret
     */
    get delete(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Engine info
     */
    get info(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        options: Record<string, any>;
        type: string;
        lease_duration: number;
        renewable: boolean;
        accessor: string;
        config: {
            default_lease_ttl: number;
            force_no_cache: boolean;
            max_lease_ttl: number;
        };
        description: string;
        external_entropy_access: boolean;
        local: boolean;
        plugin_version: string;
        running_plugin_version: string;
        running_sha256: string;
        seal_wrap: boolean;
        uuid: string;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            options: Record<string, any>;
            type: string;
            accessor: string;
            config: {
                default_lease_ttl: number;
                force_no_cache: boolean;
                max_lease_ttl: number;
            };
            description: string;
            external_entropy_access: boolean;
            local: boolean;
            plugin_version: string;
            running_plugin_version: string;
            running_sha256: string;
            seal_wrap: boolean;
            uuid: string;
            deprecation_status: string;
        };
        deprecation_status: string;
    }, VaultError>>;
}

declare class Kv2 extends ApiSector {
    /**
     * Configure the KV engine
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#configure-the-kv-engine
     */
    get config(): (args?: ({
        mountPath: string;
    } & {
        max_versions?: number | undefined;
        cas_required?: boolean | undefined;
        delete_version_after?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Read KV engine configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#read-kv-engine-configuration
     */
    get readConfig(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            max_versions: number;
            cas_required: boolean;
            delete_version_after: string;
        };
    }, VaultError>>;
    /**
     * Read secret version
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#read-secret-version
     */
    get read(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        version?: number | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            metadata: {
                version: number;
                created_time: string;
                custom_metadata: Record<string, string> | null;
                deletion_time: string;
                destroyed: boolean;
            };
            data: Record<string, string>;
        };
    }, VaultError>>;
    /**
     * Create/Update secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#create-update-secret
     */
    get write(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        data: Record<string, any>;
        options?: {
            cas: number;
            max_versions?: number | undefined;
            version?: number | undefined;
            check_and_set?: string | undefined;
            prelease?: number | undefined;
        } | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            version: number;
            created_time: string;
            custom_metadata: Record<string, string> | null;
            deletion_time: string;
            destroyed: boolean;
        };
    }, VaultError>>;
    /**
     * Patch secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#patch-secret
     */
    get patch(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        options: {
            cas: number;
            max_versions?: number | undefined;
            version?: number | undefined;
            check_and_set?: string | undefined;
            prelease?: number | undefined;
        };
        data?: any;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        data: {
            version: number;
            created_time: string;
            custom_metadata: Record<string, string> | null;
            deletion_time: string;
            destroyed: boolean;
        };
    }, VaultError>>;
    /**
     * Read secret subkeys
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#read-secret-subkeys
     */
    get subKeys(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        version?: number | undefined;
        depth?: number | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            metadata: {
                version: number;
                created_time: string;
                custom_metadata: Record<string, string> | null;
                deletion_time: string;
                destroyed: boolean;
            };
            subkeys: Record<string, any>;
        };
    }, VaultError>>;
    /**
     * Delete latest version of secret
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#delete-latest-version-of-secret
     */
    get deleteLatest(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Delete secret versions
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#delete-secret-versions
     */
    get delete(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        versions: number[];
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Undelete secret versions
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#undelete-secret-versions
     */
    get undelete(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        versions: number[];
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Destroy secret versions
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#destroy-secret-versions
     */
    get destroy(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        versions: number[];
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * List secrets
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#list-secrets
     */
    get list(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            keys: string[];
        };
    }, VaultError>>;
    /**
     * Read secret metadata
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#read-secret-metadata
     */
    get readMetadata(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            max_versions: number;
            cas_required: boolean;
            delete_version_after: string;
            created_time: string;
            custom_metadata: Record<string, string> | null;
            versions: Record<string, {
                created_time: string;
                deletion_time: string;
                destroyed: boolean;
            }>;
            current_version: number;
            oldest_version: number;
            updated_time: string;
        };
    }, VaultError>>;
    /**
     * Create/Update metadata
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#create-update-metadata
     */
    get writeMetadata(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        max_versions?: number | undefined;
        cas_required?: boolean | undefined;
        delete_version_after?: string | undefined;
        custom_metadata?: Record<string, string> | null | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Patch metadata
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#patch-metadata
     */
    get patchMetadata(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        max_versions?: number | undefined;
        cas_required?: boolean | undefined;
        delete_version_after?: string | undefined;
        custom_metadata?: Record<string, string> | null | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Delete metadata and all versions
     *
     * @link https://developer.hashicorp.com/vault/api-docs/secret/kv/kv-v2#delete-metadata-and-all-versions
     */
    get deleteMetadata(): (args?: ({
        path: string;
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Engine info
     */
    get info(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        options: Record<string, any>;
        type: string;
        lease_duration: number;
        renewable: boolean;
        accessor: string;
        config: {
            default_lease_ttl: number;
            force_no_cache: boolean;
            max_lease_ttl: number;
        };
        description: string;
        external_entropy_access: boolean;
        local: boolean;
        plugin_version: string;
        running_plugin_version: string;
        running_sha256: string;
        seal_wrap: boolean;
        uuid: string;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            options: Record<string, any>;
            type: string;
            accessor: string;
            config: {
                default_lease_ttl: number;
                force_no_cache: boolean;
                max_lease_ttl: number;
            };
            description: string;
            external_entropy_access: boolean;
            local: boolean;
            plugin_version: string;
            running_plugin_version: string;
            running_sha256: string;
            seal_wrap: boolean;
            uuid: string;
            deprecation_status: string;
        };
        deprecation_status: string;
    }, VaultError>>;
}

declare class Client {
    protected opts: ClientOptions;
    endpoint: string;
    apiVersion: string;
    pathPrefix: string;
    namespace: string | undefined;
    token: string | undefined;
    request: Partial<Omit<RequestInit, 'url'>> | undefined;
    fetcher: Fetcher | undefined;
    constructor(opts?: ClientOptions);
    /**
     * AWS secrets engine
     */
    get aws(): Aws;
    /**
     * Kubernetes secrets engine
     */
    get kubernetes(): Kubernetes;
    /**
     * Key/Value Version 1
     */
    get kv(): Kv;
    /**
     * Key/Value Version 2
     */
    get kv2(): Kv2;
    /**
     * This property is a POST command that mainly proposed to configure the vault secrets engine.
     * Also, it can be overridden by you're custom commands inside the client instance.
     */
    config: (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * This property is a GET command that resolves an HTTP GET request to the given path. Also, it
     * can be overridden by you're custom commands inside the client instance.
     */
    read: (args?: ({
        path: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * This property is a POST command that sends the `data` parameter as JSON to the given path.
     * Also, it can be overridden by you're custom commands inside the client instance.
     */
    write: (args?: ({
        path: string;
    } & {
        data: Record<string, any>;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean | Record<string, any>, VaultError>>;
    /**
     * This property is a DELETE command that resolves an HTTP DELETE request to the given path. Also,
     * it can be overridden by you're custom commands inside the client instance.
     */
    delete: (args?: ({
        path: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * This property is a LIST command that resolves an HTTP GET request to the given path. Also, it
     * can be overridden by you're custom commands inside the client instance.
     */
    list: (args?: ({
        path: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * List enabled audit devices
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/audit#list-enabled-audit-devices
     */
    get listDevices(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: Record<string, {
            options: Record<string, any>;
            type: string;
            description: string;
        }>;
    }, VaultError>>;
    /**
     * Disable audit device
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/audit#disable-audit-device
     */
    get disableDevice(): (args?: ({
        path: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Enable audit device
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/audit#enable-audit-device
     */
    get enableDevice(): (args?: ({
        path: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Query token capabilities
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/capabilities#query-token-capabilities
     */
    get queryCapabilities(): (args?: ({
        token: string;
        paths: string[];
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Seal status
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/seal-status#seal-status
     */
    get sealStatus(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        type: string;
        version: string;
        initialized: boolean;
        sealed: boolean;
        t: number;
        n: number;
        progress: number;
        nonce: string;
        build_date: string;
        migration: boolean;
        recovery_seal: boolean;
        storage_type: string;
    }, VaultError>>;
    /**
     * Read initialization status
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/init#read-initialization-status
     */
    get initialized(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        initialized: boolean;
    }, VaultError>>;
    /**
     * Start initialization
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/init#start-initialization
     */
    get init(): (args?: ({
        secret_shares: number;
        secret_threshold: number;
        pgp_keys?: string[] | undefined;
        root_token_pgp_key?: string | undefined;
        stored_shares?: number | undefined;
        recovery_shares?: number | undefined;
        recovery_threshold?: number | undefined;
        recovery_pgp_keys?: string[] | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        keys: string[];
        keys_base64: string[];
        root_token: string;
    }, VaultError>>;
    /**
     * Submit unseal key
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/unseal#submit-unseal-key
     */
    get unseal(): (args?: ({
        key: string;
        reset?: boolean | undefined;
        migrate?: boolean | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        version: string;
        sealed: true;
        t: number;
        n: number;
        progress: number;
    } | {
        version: string;
        sealed: false;
        t: number;
        n: number;
        progress: number;
        cluster_name: string;
        cluster_id: string;
    }, VaultError>>;
    /**
     * Seal
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/seal#seal
     */
    get seal(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<boolean, VaultError>>;
    /**
     * Read root generation progress
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/generate-root#read-root-generation-progress
     */
    get getRootGenerationProgress(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        progress: number;
        nonce: string;
        started: boolean;
        required: number;
        encoded_token: string;
        pgp_fingerprint: string;
        otp_length: number;
        complete: boolean;
    }, VaultError>>;
    /**
     * Start root token generation
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/generate-root#start-root-token-generation
     */
    get startRootGeneration(): (args?: ({
        otp: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        progress: number;
        nonce: string;
        started: boolean;
        required: number;
        encoded_token: string;
        otp_length: number;
        complete: boolean;
        otp: string;
    }, VaultError>>;
    /**
     * Cancel root generation
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/generate-root#cancel-root-generation
     */
    get cancelRootGeneration(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Provide key share to generate root
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/generate-root#provide-key-share-to-generate-root
     */
    get provideKeyShare(): (args?: ({
        nonce: string;
        key: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        progress: number;
        nonce: string;
        started: boolean;
        required: number;
        encoded_token: string;
        pgp_fingerprint: string;
        complete: boolean;
    }, VaultError>>;
    /**
     * List mounted secrets engines
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#list-mounted-secrets-engines
     */
    get mounts(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        warnings: string[] | null;
        data: Record<string, {
            options: Record<string, any> | null;
            type: string;
            accessor: string;
            config: Record<string, any> | null;
            description: string;
            external_entropy_access: boolean;
            local: boolean;
            plugin_version: string;
            running_plugin_version: string;
            running_sha256: string;
            seal_wrap: boolean;
            uuid: string;
        }>;
    }, VaultError>>;
    /**
     * Enable secrets engine
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#enable-secrets-engine
     */
    get mount(): (args?: ({
        mountPath: string;
    } & {
        type: string;
        config?: Record<string, string> | undefined;
        description?: string | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<unknown, VaultError>>;
    /**
     * Disable secrets engine
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#disable-secrets-engine
     */
    get unmount(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<unknown, VaultError>>;
    /**
     * Get the configuration of a secret engine
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#get-the-configuration-of-a-secret-engine
     */
    get engineInfo(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Read mount configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#read-mount-configuration
     */
    get tune(): (args?: ({
        mountPath: string;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        default_lease_ttl: number;
        force_no_cache: boolean;
        max_lease_ttl: number;
    }, VaultError>>;
    /**
     * Tune mount configuration
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/mounts#tune-mount-configuration
     */
    get tuneMount(): (args?: ({
        mountPath: string;
    } & {
        description?: string | undefined;
        plugin_version?: string | undefined;
        default_lease_ttl?: number | undefined;
        max_lease_ttl?: number | undefined;
        audit_non_hmac_request_keys?: string[] | undefined;
        audit_non_hmac_response_keys?: string[] | undefined;
        listing_visibility?: string | undefined;
        passthrough_request_headers?: string[] | undefined;
        allowed_response_headers?: string[] | undefined;
        allowed_managed_keys?: string[] | undefined;
    } & {
        [key: string]: unknown;
    }) | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<Record<string, any>, VaultError>>;
    /**
     * Read health information
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/health#read-health-information
     */
    get health(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        version: string;
        initialized: boolean;
        sealed: boolean;
        cluster_name: string;
        cluster_id: string;
        standby: boolean;
        performance_standby: boolean;
        replication_performance_mode: string;
        replication_dr_mode: string;
        server_time_utc: number;
    }, VaultError>>;
    /**
     * Collect host information
     *
     * @link https://developer.hashicorp.com/vault/api-docs/system/host-info#collect-host-information
     */
    get hostInfo(): (args?: {
        [key: string]: unknown;
    } | undefined, options?: CommandOptions) => Promise<p_safe.SafeReturn<{
        lease_duration: number;
        renewable: boolean;
        request_id: string;
        lease_id: string;
        wrap_info: Record<string, any> | null;
        warnings: Record<string, any> | null;
        auth: Record<string, any> | null;
        data: {
            cpu: {
                cpu: number;
                vendorId: string;
                family: string;
                model: string;
                stepping: number;
                physicalId: string;
                coreId: string;
                cores: number;
                modelName: string;
                mhz: number;
                cacheSize: number;
                flags: string[];
                microcode: string;
            }[];
            cpu_times: {
                cpu: string;
                user: number;
                system: number;
                idle: number;
                nice: number;
                iowait: number;
                irq: number;
                softirq: number;
                steal: number;
                guest: number;
                guestNice: number;
            }[];
            disk: {
                path: string;
                fstype: string;
                total: number;
                free: number;
                used: number;
                usedPercent: number;
                inodesTotal: number;
                inodesUsed: number;
                inodesFree: number;
                inodesUsedPercent: number;
            }[];
            host: {
                hostname: string;
                uptime: number;
                bootTime: number;
                procs: number;
                os: string;
                platform: string;
                platformFamily: string;
                platformVersion: string;
                kernelVersion: string;
                kernelArch: string;
                virtualizationSystem: string;
                virtualizationRole: string;
                hostid: string;
            };
            memory: {
                dirty: number;
                total: number;
                free: number;
                used: number;
                usedPercent: number;
                available: number;
                active: number;
                inactive: number;
                wired: number;
                laundry: number;
                buffers: number;
                cached: number;
                writeback: number;
                writebacktmp: number;
                shared: number;
                slab: number;
                sreclaimable: number;
                sunreclaim: number;
                pagetables: number;
                swapcached: number;
                commitlimit: number;
                committedas: number;
                hightotal: number;
                highfree: number;
                lowtotal: number;
                lowfree: number;
                swaptotal: number;
                swapfree: number;
                mapped: number;
                vmalloctotal: number;
                vmallocused: number;
                vmallocchunk: number;
                hugepagestotal: number;
                hugepagesfree: number;
                hugepagesize: number;
            };
            timestamp: string;
        };
    }, VaultError>>;
}

declare class VaultError extends Error {
    constructor(error: string[] | string | null);
}

declare function generateCommand<Schema extends RequestSchema, RawResponse extends boolean = false>(init: CommandInit<Schema, RawResponse>, raw?: boolean): (args?: Infer<Schema["path"]> & Infer<Schema["searchParams"]> & Infer<Schema["headers"]> & Infer<Schema["body"]> & {
    [key: string]: unknown;
}, options?: CommandOptions) => Promise<SafeReturn<RawResponse extends true ? Response : Infer<Schema["response"]>, VaultError>>;

export { Client, type ClientOptions, type CommandArgs, type CommandInit, type CommandOptions, type Fetcher, type Infer, type RequestSchema, VaultError, generateCommand };
